# TestCaseUpdateFieldDto


## Enum

* `NAME` (value: `'name'`)

* `FULL_NAME` (value: `'full_name'`)

* `TEST_LAYER` (value: `'test_layer'`)

* `DESCRIPTION` (value: `'description'`)

* `PRECONDITION` (value: `'precondition'`)

* `EXPECTED_RESULT` (value: `'expected_result'`)

* `LINK` (value: `'link'`)

* `TAG` (value: `'tag'`)

* `ISSUE` (value: `'issue'`)

* `MEMBER` (value: `'member'`)

* `CUSTOM_FIELD` (value: `'custom_field'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


